import sys
import re


def printstat(data, stat):
    print("- {} -".format(stat))

    s = {}

    for d in data:
        value = d[stat]

        if value in s:
            s[value] += 1
        else:
            s[value] = 1

    sorted_keys = sorted(s, key=s.get, reverse=True)

    for key in sorted_keys:
        print("{} {}".format(s[key], key))


def parse(text):
    data = []

    for line in text:
        match = re.search(r'(\S+) (\S+) (\S+) \[(.*?)\] "(.*)" '
                          r'(\S+) (\S+) "(.*)" "(.*)"', line)
        if match:
            groups = match.groups()
            data.append({
                "ip": groups[0],
                "request": groups[4],
                "useragent": groups[-1],
            })

            if len(data) >= 100:
                break

    return data


def usage_and_die():
    print("parser.py [FLAGS]... [FILES]...")
    print("Parse log files")
    print("")
    print("  --ip        by ip")
    print("  --request   by request")
    print("  --useragent by useragent")
    sys.exit(1)


def main():
    if len(sys.argv) < 2:
        usage_and_die()

    stat_by = []
    files = []

    for arg in sys.argv[1:]:
        if arg in ["--ip", "--request", "--useragent"]:
            stat_by.append(arg[2:])
        else:
            files.append(arg)

    for f in files:
        print("=== {} ===".format(f))

        text = open(f).readlines()

        data = parse(text)

        for stat in stat_by:
            printstat(data, stat)
        #print(text)


    # print(stat_by)
    # print(files)


if __name__ == "__main__":
    main()
